@@ -228,8 +228,9 @@ class bigjob(api.base.bigjob):
             
             
         # Determine whether target machine use gsissh or ssh to logon.
+        logger.debug("Detect launch method for: " + lrms_saga_url.host)        
         self.launch_method = self.__get_launch_method(lrms_saga_url.host,lrms_saga_url.username)
-            
+        self.bigjob_working_directory_url=""
         ##############################################################################
         # File Management and Stage-In
         if lrms_saga_url.scheme.startswith("condor")==False:           
@@ -238,27 +239,29 @@ class bigjob(api.base.bigjob):
             # Fallback if working directory is not a valid URL
             if not (self.working_directory.startswith("go:") or self.working_directory.startswith("ssh://")):            
                 if lrms_saga_url.username!=None and lrms_saga_url.username!="":
-                    bigjob_working_directory_url = "ssh://" + lrms_saga_url.username + "@" + lrms_saga_url.host + self.__get_bigjob_working_dir()
+                    self.bigjob_working_directory_url = "ssh://" + lrms_saga_url.username + "@" + lrms_saga_url.host + self.__get_bigjob_working_dir()
                 else:
-                    bigjob_working_directory_url = "ssh://" + lrms_saga_url.host + self.__get_bigjob_working_dir()
+                    self.bigjob_working_directory_url = "ssh://" + lrms_saga_url.host + self.__get_bigjob_working_dir()
+            elif self.working_directory.startswith("go:"):
+                    self.bigjob_working_directory_url=os.path.join(self.working_directory, self.uuid)
             else:
                 # working directory is a valid file staging URL
-                bigjob_working_directory_url=self.working_directory            
+                self.bigjob_working_directory_url=self.working_directory            
                 
             # initialize file manager that takes care of file movement and directory creation
             if self.__filemanager==None:
-                self.__initialize_pilot_data(bigjob_working_directory_url) # determines the url
+                self.__initialize_pilot_data(self.bigjob_working_directory_url) # determines the url
             
             if self.__filemanager != None and not self.working_directory.startswith("/"):
-                self.working_directory = self.__filemanager.get_path(bigjob_working_directory_url)
+                self.working_directory = self.__filemanager.get_path(self.bigjob_working_directory_url)
             
             # determine working directory of bigjob 
             # if a remote sandbox can be created via ssh => create a own dir for each bj job id
             # otherwise use specified working directory
-            logger.debug("BigJob working directory: %s"%bigjob_working_directory_url)
-            if self.__filemanager!=None and self.__filemanager.create_remote_directory(bigjob_working_directory_url)==True:
+            logger.debug("BigJob working directory: %s"%self.bigjob_working_directory_url)
+            if self.__filemanager!=None and self.__filemanager.create_remote_directory(self.bigjob_working_directory_url)==True:
                 self.working_directory = self.__get_bigjob_working_dir()
-                self.__stage_files(filetransfers, bigjob_working_directory_url)
+                self.__stage_files(filetransfers, self.bigjob_working_directory_url)
             else:        
                 logger.warn("For file staging. SSH (incl. password-less authentication or Globus Online is required.")
             
@@ -666,7 +669,9 @@ bigjob_agent = bigjob.bigjob_agent.bigjob_agent(args)
     
     
     def __get_subjob_working_dir(self, sj_id):
-        return os.path.join(self.__get_bigjob_working_dir(), sj_id)
+        base_url = self.bigjob_working_directory_url 
+        url  = os.path.join(base_url, sj_id)        
+        return url
     
 
     ###########################################################################
@@ -682,6 +687,7 @@ bigjob_agent = bigjob.bigjob_agent.bigjob_agent(args)
                 self.__filemanager = SSHFileAdaptor(service_url) 
             except:
                 logger.warn("SSH/Paramiko package not found.")            
+                self.__print_traceback()
         elif service_url.startswith("http:"):
             logger.debug("Use WebHDFS backend")
             try:
@@ -723,25 +729,35 @@ bigjob_agent = bigjob.bigjob_agent.bigjob_agent(args)
     def __get_launch_method(self, hostname, user=None):
         """ returns desired execution method: ssh, aprun """
         if user == None: user = self.__discover_ssh_user(hostname)
-        if user!=None: logger.debug("discovered user: " + user)
+        host = ""
+        if user!=None and user!="": 
+            logger.debug("discovered user: " + user)
+            host = user + "@" + hostname
+        else:
+            host = hostname 
         gsissh_available = False
         try:
-            gsissh_available = (subprocess.call("gsissh "+ user + "@" + hostname+" /bin/date", shell=True,stdout=subprocess.PIPE,stderr=subprocess.PIPE)==0)
+            cmd = "gsissh " + host + " /bin/date"
+            logger.debug("Execute: " + cmd)
+            gsissh_available = (subprocess.call(cmd, shell=True)==0)
         except:
             pass
     
         ssh_available = False
         try:
-            ssh_available = (subprocess.call("ssh "+ user + "@" + hostname+" /bin/date", shell=True, stdout=subprocess.PIPE,stderr=subprocess.PIPE)==0)
+            cmd = "ssh " + host + " /bin/date"
+            logger.debug("Execute: " + cmd)
+            ssh_available = (subprocess.call(cmd, shell=True)==0)
         except:
             pass
+        logger.debug("SSH avail: %r GSISSH avail: %r"%(ssh_available, gsissh_available))
     
         launch_method = "ssh"
         if ssh_available == False and gsissh_available == True:
             launch_method="gsissh"
         else:
             launch_method="ssh"
-        logging.debug(" launch method used " + str(launch_method))
+        logger.debug("Use launch method: " + str(launch_method))
         return launch_method
     
     
